@@ -70,7 +70,6 @@ class Project(Model):
     number = models.PositiveIntegerField(default=auto_increment_project_number, editable=False)
     creationDate = models.DateField(auto_now_add=True)
     customer = models.ForeignKey(Customer, on_delete=models.SET_NULL, null=True, blank=True)
-    team = models.ManyToManyField(settings.AUTH_USER_MODEL, through='Member', blank=True)
     captain = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.SET_NULL, blank=True, null=True,
                                 related_name='+')
     driveID = models.TextField(null=True, blank=True)
@@ -79,7 +78,9 @@ class Project(Model):
     jabberRoom = models.BooleanField(default=True)
 
     class Meta(Model.Meta):
-        nested_fields = ['team', 'customer', 'members']
+        empty_containers = ["captain"]
+#        depth = 1 # Disabled due to captain being serialized
+        nested_fields = ['customer', 'members']
         permission_classes = [ProjectPermissions]
         anonymous_perms = []
         authenticated_perms = []
