@@ -37,6 +37,6 @@ class ProjectsJoinableViewset(LDPViewSet):
     filter_backends = [LocalObjectFilterBackend]
 
     def get_queryset(self):
-        return super().get_queryset().exclude(team__id=self.request.user.id)\
+        return super().get_queryset().exclude(members__user=self.request.user.id)\
             .exclude(status="Private")\
             .exclude(status="Archived")
